require 'guard/bosh/template_checker'

require 'guard/bosh/effective_properties_calculator'

describe Guard::Bosh::TemplateChecker do
  let(:properties_calculator) do
    instance_double(Guard::Bosh::EffectivePropertiesCalculator)
  end
  let(:apply_specification) do
    instance_double(Guard::Bosh::ApplySpecification)
  end
  let(:template_renderer) do
    instance_double(Guard::Bosh::TemplateRenderer)
  end
  subject do
    Guard::Bosh::TemplateChecker.new(
      deployment_manifest: 'a/deployment/manifest.yml',
      properties_calculator: properties_calculator,
      apply_specification: apply_specification,
      template_renderer: template_renderer
    )
  end

  before do
    allow(properties_calculator).to receive(:calculate_effective_properties)
    allow(apply_specification).to receive(:generate).and_return(
      'apply' => 'specification')
    allow(template_renderer).to receive(:render)
  end

  it 'builds a context to evaluate the template in' do
    expect(properties_calculator).to receive(
      :calculate_effective_properties).with(
        manifest_job_name: 'redis_leader_z1',
        job_name: 'redis'
    ).and_return('effective' => 'properties')
    expect(apply_specification).to receive(:generate).with(
      properties: { 'effective' => 'properties' },
      job_name: 'redis_leader_z1')
    subject.check(
      manifest_job_name: 'redis_leader_z1',
      job_name: 'redis',
      template: 'jobs/redis/templates/redis.conf.erb'
    )
  end

  it 'renders the template in context' do
    expect(template_renderer).to receive(:render).with(
      context: { 'apply' => 'specification' },
      template: 'jobs/redis/templates/redis.conf.erb'
    )
    subject.check(
      manifest_job_name: 'redis_leader_z1',
      job_name: 'redis',
      template: 'jobs/redis/templates/redis.conf.erb'
    )
  end

  it 'returns any errors generated by the template render' do
    expect(template_renderer).to receive(:render).and_return(
      ['missing property'])
    errors = subject.check(
      manifest_job_name: 'redis_leader_z1',
      job_name: 'redis',
      template: 'jobs/redis/templates/redis.conf.erb'
    )
    expect(errors).to eq(['missing property'])
  end
end
